@@ -16,7 +16,7 @@ use Tickit::Window;
 use Tickit::Utils qw( textwidth );
 use Tickit::RenderBuffer;
 
-our $VERSION = '0.20';
+our $VERSION = '0.21';
 
 use Carp;
 
@@ -442,7 +442,7 @@ sub shift :method
    my ( $lastline, $offscreen ) = $self->item2line( $count - 1, -1 );
 
    if( defined $lastline ) {
-      $self->scroll( $lastline + 1);
+      $self->scroll( $lastline + 1, allow_gap => 1 );
       # ->scroll implies $win->restore
    }
 
@@ -518,7 +518,7 @@ occupy multiple lines, then fewer items may be scrolled than lines.
 sub scroll
 {
    my $self = shift;
-   my ( $delta ) = @_;
+   my ( $delta, %opts ) = @_;
 
    return unless $delta;
 
@@ -570,7 +570,7 @@ REDO:
 
    my $lines = $self->{window_lines};
 
-   if( $scroll_amount > 0 ) {
+   if( $scroll_amount > 0 and !$opts{allow_gap} ) {
       # We scrolled down. See if we've gone too far
       my $line = -$partial;
       my $idx = $itemidx;
